SystemOrganization addCategory: #SeasideSwazoo!

!HTTPRequest methodsFor: '*SeasideSwazoo' stamp: 'pmm 8/31/2007 11:03'!
remoteAddress
	^self peer! !

!SwazooServer class methodsFor: '*SeasideSwazoo' stamp: 'pmm 8/31/2007 10:52'!
seasideStart
	self singleton seasideStart! !

!SwazooServer class methodsFor: '*SeasideSwazoo' stamp: 'pmm 8/31/2007 10:53'!
seasideStop
	self singleton seasideStop! !

!SwazooServer methodsFor: '*SeasideSwazoo' stamp: 'pmm 8/30/2007 12:54'!
seasideStart
	(self siteNamed: 'seasidedemo') isNil ifTrue:
		[SeasideSite newNamed: 'seasidedemo'.
		(SeasideSite named: 'seasidedemo') host: 'localhost' ip: '127.0.0.1'  port: 8888].
	self startSite: 'seasidedemo'! !

!SwazooServer methodsFor: '*SeasideSwazoo' stamp: 'pmm 8/30/2007 12:56'!
seasideStop
	self stopSite: 'seasidedemo'! !

Site subclass: #SeasideSite
	instanceVariableNames: 'dispatcher'
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideSwazoo'!

!SeasideSite methodsFor: 'serving' stamp: 'pmm 9/1/2007 10:39'!
answerTo: aSwazooRequest
	| response |

	response := self dispatcher handleRequest: (self convertRequest: aSwazooRequest).
	^ self convertResponse: response! !

!SeasideSite methodsFor: 'private' stamp: 'pmm 9/1/2007 14:01'!
convertRequest: aSwazooRequest
	^WARequest
		method: (aSwazooRequest isPost
			ifTrue: [ 'POST' ]
			ifFalse: [ 'GET' ])
		url: aSwazooRequest uriString
		headers: aSwazooRequest headers fields
		fields: (self parseFields: aSwazooRequest )
		cookies: (self parseCookies: aSwazooRequest)
		nativeRequest: aSwazooRequest! !

!SeasideSite methodsFor: 'private' stamp: 'pmm 9/1/2007 10:38'!
convertResponse: aSeasideResponse
	| swazooResponse |
	swazooResponse := HTTPResponse new.
			
	aSeasideResponse headers do: [ :each |
		| field fieldClass |
		fieldClass := HeaderField classForFieldName: each key.
		field := fieldClass newForFieldName: each key withValueFrom: each value.
		swazooResponse headers addField: field ].
	aSeasideResponse cookies do: [ :each | 
		swazooResponse cookie: (self cookieHeaderFor: each) ].
	swazooResponse code: aSeasideResponse status asNumber.

	swazooResponse entity: aSeasideResponse contents contents.
	swazooResponse contentType: aSeasideResponse contentType.

	aSeasideResponse release.
	^swazooResponse! !

!SeasideSite methodsFor: 'private' stamp: 'pmm 8/31/2007 11:53'!
cookieHeaderFor: aCookie
	^String streamContents: [ :stream |
		stream
			nextPutAll: aCookie key;
			nextPutAll: '=';
			nextPutAll: (aCookie value ifNil: [ '' ]).
		aCookie path isNil ifFalse: [
			stream
				nextPutAll: '; path=';
				nextPutAll: aCookie path ].
		aCookie expiry isNil ifFalse: [
			stream
				nextPutAll: '; expires=';
				nextPutAll: aCookie expiryString ] ]! !

!SeasideSite methodsFor: 'accessing' stamp: 'pmm 8/30/2007 13:10'!
dispatcher
	^WADispatcher default! !

!SeasideSite methodsFor: 'serving-private' stamp: 'pmm 8/30/2007 12:52'!
helpResolve: aResolution 
	(self canAnswer and: [aResolution siteMatch: self]) ifFalse: [^nil].
	^self answerTo: aResolution request! !

!SeasideSite methodsFor: 'private' stamp: 'pmm 9/3/2007 19:27'!
parseCookies: aSwazooRequest
	| cookies swazooCookies cookieLine |
	cookies := Dictionary new.
	cookieLine := aSwazooRequest cookie.
	cookieLine isEmptyOrNil ifTrue: [ ^cookies ]. 
	swazooCookies := cookieLine findTokens: $;.
	swazooCookies do: [ :each |
		| pair key value |
		pair := each findTokens: $=.
		key := pair first withBlanksTrimmed.
		value := pair size > 1
			ifTrue: [ pair second withBlanksTrimmed ]
			ifFalse: [ nil ].
		cookies at: key put: value ].
 	^cookies! !

!SeasideSite methodsFor: 'private' stamp: 'pmm 9/1/2007 14:14'!
parseFields: aSwazooRequest
	| fields |
	fields := Dictionary new.
	aSwazooRequest isPost
		ifTrue: [
			aSwazooRequest postDataKeys do: [ :key |
				| data value |
				data := aSwazooRequest postDataAt: key.
				value := data filename isNil
					ifTrue: [ data value ]
					ifFalse: [
						WAFile new
							fileName: data filename;
							contentType: data contentType;
							contents: data value;
							yourself ].
				fields at: key put: value value ] ]
		ifFalse: [
			aSwazooRequest queries do: [ :each |
				fields at: each key put: each value ] ].
	^fields! !

SeasideSite subclass: #SeasideStreamSite
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'SeasideSwazoo'!

!SeasideStreamSite methodsFor: 'accessing' stamp: 'pmm 9/1/2007 12:28'!
convertRequest: aSwazooRequest
	^(super convertRequest: aSwazooRequest)
		responseStream: aSwazooRequest parent stream;
		yourself! !
